@@ -10,7 +10,8 @@
 #'   `show_data` can be "points" (the points of the original data corresponding
 #'   to the x and y axes), "density_2d", "density_2d_filled",
 #'   "density_2d_polygon" or "density_2d_raster".
-#' @param point,jitter,boxplot,violin,pointrange,density_2d,line,hline,ribbon,labs,facet_wrap Additional aesthetics and parameters for the geoms (see customization example).
+#' @param point,jitter,boxplot,violin,pointrange,density_2d,line,hline,ribbon,labs,facet_wrap Additional
+#' aesthetics and parameters for the geoms (see customization example).
 #' @param ... Other arguments passed to other functions.
 #'
 #' @examples
@@ -161,10 +162,8 @@ visualisation_recipe.estimate_predicted <- function(x,
   targets <- targets[targets != x1] # Remove from target list
 
   # if x-axis a factor, we jitter the points
-  if (!is.numeric(data[[x1]])) {
-    if (show_data %in% c("point", "points")) {
-      show_data <- "jitter"
-    }
+  if (!is.numeric(data[[x1]]) && show_data %in% c("point", "points")) {
+    show_data <- "jitter"
   }
 
 
@@ -201,9 +200,9 @@ visualisation_recipe.estimate_predicted <- function(x,
   }
 
   # 4+ interaction
-  if (length(targets) > 0) {
+  if (length(targets) > 0L) {
     # TODO: We could add the fourth term as facets
-    warning("It seems like more than 4 focal terms are present. Not sure how to plot it, so keeping only the 3 first variables (however, this might not be a good visualisation of your model).", call. = FALSE)
+    insight::format_warning("It seems like more than 4 focal terms are present. Not sure how to plot it, so keeping only the 3 first variables (however, this might not be a good visualisation of your model).")
   }
 
 
@@ -211,7 +210,7 @@ visualisation_recipe.estimate_predicted <- function(x,
   l <- 1
 
   # Raw data ---------------------
-  if (!is.null(show_data) && all(show_data != "none") && !all(show_data == FALSE)) {
+  if (!is.null(show_data) && all(show_data != "none") && !all(isFALSE(show_data))) {
     rawdata <- .visualisation_recipe_getrawdata(x)
 
     # Nicer points
@@ -269,13 +268,18 @@ visualisation_recipe.estimate_predicted <- function(x,
   # Uncertainty -----------------------------------
 
   # Get CIs (reverse so that larger CIs are first)
-  ci_lows <- rev(names(data)[grepl("CI_low", names(data), fixed = TRUE)])
-  ci_highs <- rev(names(data)[grepl("CI_high", names(data), fixed = TRUE)])
+  ci_lows <- rev(grep("CI_low", names(data), fixed = TRUE, value = TRUE))
+  ci_highs <- rev(grep("CI_high", names(data), fixed = TRUE, value = TRUE))
 
   # Ribbon
   if (is.numeric(data[[x1]]) && (is.null(x3) || !is.numeric(data[[x2]])) && is.null(x3)) {
     if ("iter_1" %in% names(data)) {
-      layers[[paste0("l", l)]] <- .visualisation_predicted_iterations(data, x1, fill = color, ribbon = ribbon)
+      layers[[paste0("l", l)]] <- .visualisation_predicted_iterations(
+        data,
+        x1,
+        fill = color,
+        ribbon = ribbon
+      )
       l <- l + 1
     } else {
       for (i in seq_len(length(ci_lows))) {
@@ -315,7 +319,7 @@ visualisation_recipe.estimate_predicted <- function(x,
   # Predicted -----------------------------------
 
   # Line
-  if (skip_line == FALSE) {
+  if (isFALSE(skip_line)) {
     layers[[paste0("l", l)]] <- .visualisation_predicted_line(
       data,
       x1,
@@ -472,7 +476,7 @@ visualisation_recipe.estimate_predicted <- function(x,
     alpha = alpha
   )
 
-  if (jitter == TRUE) {
+  if (isTRUE(jitter)) {
     insight::check_if_installed("ggplot2")
     out$position <- ggplot2::position_dodge2(width = 0.25)
   }
